@@ -21,7 +21,7 @@ NUMERIC_REGEX = re.compile(r"\s*\d+\s*")
 DEFAULT_BIN_DIRS = [os.path.join(ROOT_DIR, "usr", "bin"), os.path.join(
     ROOT_DIR, "usr", "local", "bin")]
 PY2 = sys.version[0] == "2"
-
+DEFAULT_PYTHON_APP_NAME = "Python Application"
 
 class RunMode:
     """Py2 compatible enum."""
@@ -297,7 +297,10 @@ class Process(object):
 
         return tuple(admin_command)
 
-    def get_app_name(self):
+    def get_app_name(self, args):
+        if args.yes:
+            return DEFAULT_PYTHON_APP_NAME
+
         print("\nOriginal process run with:\n", self.command)
         app_name = get_input("Enter an application name: ").strip()
         if app_name:
@@ -309,7 +312,7 @@ class Process(object):
 
     def generate_newrelic_config(self, args, ini_path):
         if not os.path.exists(ini_path) or args.yes or yes_no_input("\nnewrelic.ini file detected at %s. Would you like to overwrite it?" % str(ini_path)):
-            app_name = args.appName or self.get_app_name()
+            app_name = args.appName or self.get_app_name(args)
             subprocess.call(
                 [self.newrelic_admin, "generate-config",
                     args.licenseKey, str(ini_path)]
@@ -328,7 +331,7 @@ class Process(object):
                 dt_replaced_text = file_text.replace(replace, replace_with)
 
                 final_config = dt_replaced_text.replace(
-                    "Python Application", app_name)
+                    DEFAULT_PYTHON_APP_NAME, app_name)
 
                 file.write(final_config)
 
@@ -511,6 +514,19 @@ def require_arg_defined(arg, args):
         sys.exit(1)
 
 
+def require_pid(args):
+    try:
+        pid = int(args.pid)
+    except ValueError:
+        sys.stderr.write("--pid must be an integer, got %s\n" % str(args.pid))
+        sys.exit(1)
+
+    require_arg_defined("pid", args)
+    if not Process(pid).exists:
+        sys.stderr.write("--process with id %d does not exist\n" % pid)
+        sys.exit(1)
+
+
 def main():
     parser = argparse.ArgumentParser()
 
@@ -557,6 +573,7 @@ def main():
         "-r",
         "--region",
         choices=['US', 'EU', 'STAGING'],
+        type=str.upper,
         help="the region to report into",
         default=os.environ.get('NEW_RELIC_REGION', "US"),
         dest="region",
@@ -588,13 +605,13 @@ def main():
     if args.mode == RunMode.LIST:
         list_instrumentable_pids(args)
     elif args.mode == RunMode.INTROSPECT:
-        require_arg_defined("pid", args)
+        require_pid(args)
         introspect_pid(args)
     elif args.mode == RunMode.INSTALL:
-        require_arg_defined("pid", args)
+        require_pid(args)
         install_pid(args)
     elif args.mode == RunMode.INSTRUMENT:
-        require_arg_defined("pid", args)
+        require_pid(args)
         require_arg_defined("licenseKey", args)
         instrument_pid(args)
 
